==> zio-aws-securityhub_2.13-5.17.128.1-sources.jar: zio/aws/securityhub/model/AwsSqsQueueDetails.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.{NonEmptyString, Integer}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AwsSqsQueueDetails(
    kmsDataKeyReusePeriodSeconds: Option[Integer] = None,
    kmsMasterKeyId: Option[NonEmptyString] = None,
    queueName: Option[NonEmptyString] = None,
    deadLetterTargetArn: Option[NonEmptyString] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.AwsSqsQueueDetails = {
    import AwsSqsQueueDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.AwsSqsQueueDetails
      .builder()
      .optionallyWith(
        kmsDataKeyReusePeriodSeconds.map(value =>
          Integer.unwrap(value): java.lang.Integer
        )
      )(_.kmsDataKeyReusePeriodSeconds)
      .optionallyWith(
        kmsMasterKeyId.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.kmsMasterKeyId)
      .optionallyWith(
        queueName.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.queueName)
      .optionallyWith(
        deadLetterTargetArn.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.deadLetterTargetArn)
      .build()
  }
  def asReadOnly: zio.aws.securityhub.model.AwsSqsQueueDetails.ReadOnly =
    zio.aws.securityhub.model.AwsSqsQueueDetails.wrap(buildAwsValue())
}
object AwsSqsQueueDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.AwsSqsQueueDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.securityhub.model.AwsSqsQueueDetails =
      zio.aws.securityhub.model.AwsSqsQueueDetails(
        kmsDataKeyReusePeriodSeconds.map(value => value),
        kmsMasterKeyId.map(value => value),
        queueName.map(value => value),
        deadLetterTargetArn.map(value => value)
      )
    def kmsDataKeyReusePeriodSeconds: Option[Integer]
    def kmsMasterKeyId: Option[NonEmptyString]
    def queueName: Option[NonEmptyString]
    def deadLetterTargetArn: Option[NonEmptyString]
    def getKmsDataKeyReusePeriodSeconds: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField(
        "kmsDataKeyReusePeriodSeconds",
        kmsDataKeyReusePeriodSeconds
      )
    def getKmsMasterKeyId: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("kmsMasterKeyId", kmsMasterKeyId)
    def getQueueName: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("queueName", queueName)
    def getDeadLetterTargetArn: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("deadLetterTargetArn", deadLetterTargetArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.AwsSqsQueueDetails
  ) extends zio.aws.securityhub.model.AwsSqsQueueDetails.ReadOnly {
    override val kmsDataKeyReusePeriodSeconds: Option[Integer] = scala
      .Option(impl.kmsDataKeyReusePeriodSeconds())
      .map(value => zio.aws.securityhub.model.primitives.Integer(value))
    override val kmsMasterKeyId: Option[NonEmptyString] = scala
      .Option(impl.kmsMasterKeyId())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val queueName: Option[NonEmptyString] = scala
      .Option(impl.queueName())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val deadLetterTargetArn: Option[NonEmptyString] = scala
      .Option(impl.deadLetterTargetArn())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.AwsSqsQueueDetails
  ): zio.aws.securityhub.model.AwsSqsQueueDetails.ReadOnly = new Wrapper(impl)
}

==> zio-aws-securityhub_2.13-5.17.148.1-sources.jar: zio/aws/securityhub/model/AwsSqsQueueDetails.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.{NonEmptyString, Integer}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AwsSqsQueueDetails(
    kmsDataKeyReusePeriodSeconds: Option[Integer] = None,
    kmsMasterKeyId: Option[NonEmptyString] = None,
    queueName: Option[NonEmptyString] = None,
    deadLetterTargetArn: Option[NonEmptyString] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.AwsSqsQueueDetails = {
    import AwsSqsQueueDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.AwsSqsQueueDetails
      .builder()
      .optionallyWith(
        kmsDataKeyReusePeriodSeconds.map(value => value: java.lang.Integer)
      )(_.kmsDataKeyReusePeriodSeconds)
      .optionallyWith(
        kmsMasterKeyId.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.kmsMasterKeyId)
      .optionallyWith(
        queueName.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.queueName)
      .optionallyWith(
        deadLetterTargetArn.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.deadLetterTargetArn)
      .build()
  }
  def asReadOnly: zio.aws.securityhub.model.AwsSqsQueueDetails.ReadOnly =
    zio.aws.securityhub.model.AwsSqsQueueDetails.wrap(buildAwsValue())
}
object AwsSqsQueueDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.AwsSqsQueueDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.securityhub.model.AwsSqsQueueDetails =
      zio.aws.securityhub.model.AwsSqsQueueDetails(
        kmsDataKeyReusePeriodSeconds.map(value => value),
        kmsMasterKeyId.map(value => value),
        queueName.map(value => value),
        deadLetterTargetArn.map(value => value)
      )
    def kmsDataKeyReusePeriodSeconds: Option[Integer]
    def kmsMasterKeyId: Option[NonEmptyString]
    def queueName: Option[NonEmptyString]
    def deadLetterTargetArn: Option[NonEmptyString]
    def getKmsDataKeyReusePeriodSeconds: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField(
        "kmsDataKeyReusePeriodSeconds",
        kmsDataKeyReusePeriodSeconds
      )
    def getKmsMasterKeyId: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("kmsMasterKeyId", kmsMasterKeyId)
    def getQueueName: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("queueName", queueName)
    def getDeadLetterTargetArn: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("deadLetterTargetArn", deadLetterTargetArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.AwsSqsQueueDetails
  ) extends zio.aws.securityhub.model.AwsSqsQueueDetails.ReadOnly {
    override val kmsDataKeyReusePeriodSeconds: Option[Integer] = scala
      .Option(impl.kmsDataKeyReusePeriodSeconds())
      .map(value => value: Integer)
    override val kmsMasterKeyId: Option[NonEmptyString] = scala
      .Option(impl.kmsMasterKeyId())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val queueName: Option[NonEmptyString] = scala
      .Option(impl.queueName())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val deadLetterTargetArn: Option[NonEmptyString] = scala
      .Option(impl.deadLetterTargetArn())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.AwsSqsQueueDetails
  ): zio.aws.securityhub.model.AwsSqsQueueDetails.ReadOnly = new Wrapper(impl)
}
